@@ -6,7 +6,7 @@ def bbedit(self):
     filename = self.canonic(frame.f_code.co_filename)
     if exists(filename):
         filename = realpath(filename)
-        system('bbedit +%s -b %s' % (lineno, filename))
+        system('bbedit +%s -b "%s"' % (lineno, filename))
 
 def preloop(self):
     bbedit(self)
